@@ -1,37 +1,41 @@
 package Async::Hooks;
+{
+  $Async::Hooks::VERSION = '0.06';
+}
 
-use 5.008;
-use Mouse;
+# ABSTRACT: Hook system with asynchronous capabilities
+
+use Mo qw(is default);
+use Carp 'confess';
 use Async::Hooks::Ctl;
+use namespace::clean;
 
-our $VERSION = '0.05';
 
 has registry => (
-  isa => 'HashRef',
-  is  => 'ro',
-  default =>  sub { {} }, 
+  is      => 'ro',
+  default => sub { {} },
 );
 
 
 sub hook {
   my ($self, $hook, $cb) = @_;
-  
+
   confess("Missing first parameter, the hook name, ") unless $hook;
   confess("Missing second parameter, the coderef callback, ")
     unless ref($cb) eq 'CODE';
-  
+
   my $cbs = $self->{registry}{$hook} ||= [];
   push @$cbs, $cb;
-  
+
   return;
 }
 
 
 sub has_hooks_for {
   my ($self, $hook) = @_;
-  
+
   confess("Missing first parameter, the hook name, ") unless $hook;
-  
+
   my $reg = $self->{registry};
   return 0 unless exists $reg->{$hook};
   return scalar(@{$reg->{$hook}});
@@ -40,69 +44,71 @@ sub has_hooks_for {
 
 sub call {
   my ($self, $hook, $args, $cleanup) = @_;
-  
+  ($args, $cleanup) = (undef, $args) if ref($args) eq 'CODE' && !$cleanup;
+
   confess("Missing first parameter, the hook name, ") unless $hook;
   confess("Second parameter, the arguments list, must be a arrayref, ")
     if $args && ref($args) ne 'ARRAY';
   confess("Third parameter, the cleanup callback, must be a coderef, ")
     if $cleanup && ref($cleanup) ne 'CODE';
-  
+
   my $r = $self->{registry};
-  my $cbs = exists $r->{$hook}? $r->{$hook} : [];
-  
+  my $cbs = exists $r->{$hook} ? $r->{$hook} : [];
+
   return Async::Hooks::Ctl->new([@$cbs], $args, $cleanup)->next;
 }
 
 
-no Mouse;
-__PACKAGE__->meta->make_immutable;
+1;    # End of Async::Hooks
+
+
+__END__
+=pod
 
 =head1 NAME
 
 Async::Hooks - Hook system with asynchronous capabilities
 
-
 =head1 VERSION
 
-Version 0.01
-
+version 0.06
 
 =head1 SYNOPSIS
 
     use Async::Hooks;
-    
+
     my $nc = Async::Hooks->new;
-    
+
     # Hook a callback on 'my_hook_name' chain
     $nc->hook('my_hook_name', sub {
       my ($ctl, $args) = @_;
       my $url = $args->[0];
-      
+
       # Async HTTP get, calls sub when it finishes
       http_get($url, sub {
         my ($data) = @_;
-        
+
         return $ctl->done unless defined $data;
 
         # You can use unused places in $args as a stash
         $args->[1] = $data;
-        
+
         $ctl->next;
       });
     });
-    
+
     $nc->hook('my_hook_name', sub {
       my ($ctl, $args) = @_;
-      
+
       # example transformation
       $args->[1] =~ s/(</?)(\w+)/"$1".uc($2)/ge;
-      
+
       $ctl->next;
     });
-    
+
     # call hook with arguments
     $nc->call('my_hook_name', ['http://search.cpan.org/']);
-    
+
     # call hook with arguments and cleanup
     $nc->call('my_hook_name', ['http://search.cpan.org/'], sub {
       my ($ctl, $args, $is_done) = @_;
@@ -115,7 +121,6 @@ Version 0.01
       }
     });
 
-
 =head1 DESCRIPTION
 
 This module allows you to create hooks on your own modules that other
@@ -199,15 +204,15 @@ module to make a HTTP request, you could do something like this:
     sub check_server_is_up_cb {
       my ($ctl, $args) = @_;
       my ($url) = @$args;
-      
+
       http_get($url, sub {
         my ($data, $headers) = @_;
-        
+
         if (defined $data) {
           push @$args = $data;
           return $ctl->done;
         }
-        
+
         return $ctl->next;
       });
     }
@@ -218,7 +223,6 @@ process the result. If a sucessful result is found, we stop the chain.
 While the HTTP request is being made, your application can keep on
 processing other tasks.
 
-
 =head1 METHODS
 
 =over 4
@@ -238,7 +242,7 @@ The callback will be called with two parameters: a
 L<Async::Hooks::Ctl|Async::Hooks::Ctl> object and an arrayref with
 arguments.
 
-=item $registry->call($hook_name, \@args, \&cleanup)
+=item $registry->call($hook_name [, \@args] [, \&cleanup])
 
 Calls a specific hook name chain. You can optionally provide an arrayref
 with arguments that each callback will receive.
@@ -252,7 +256,6 @@ Returns the number of callbacks registered with C<$hook>.
 
 =back
 
-
 =head1 SEE ALSO
 
 There are a couple of modules that do similar things to this one:
@@ -273,48 +276,6 @@ Of those four, only L<Object::Event|Object::Event> version 1.0 and later
 provides the same ability to pause a chain, do some asynchrounous work
 and resume chain processing later.
 
-
-=head1 AUTHOR
-
-Pedro Melo, C<< <melo at cpan.org> >>
-
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-async-hooks at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Async-Hooks>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Async::Hooks
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Async-Hooks>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Async-Hooks>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Async-Hooks>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Async-Hooks>
-
-=back
-
-
 =head1 ACKNOWLEDGEMENTS
 
 The code was inspired by the C<run_hook_chain> and C<hook_chain_fast>
@@ -322,15 +283,17 @@ code of the L<DJabberd project|DJabberd> (see the
 L<DJabberd::VHost|DJabberd::VHost> module source code). Hat tip to Brad
 Fitzpatrick.
 
+=head1 AUTHOR
 
-=head1 COPYRIGHT & LICENSE
+Pedro Melo <melo@cpan.org>
 
-Copyright 2009 Pedro Melo, all rights reserved.
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is Copyright (c) 2011 by Pedro Melo.
 
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
-1; # End of Async::Hooks
